struct NoopServerCertVerifier;Trait Implementations
Sourceimpl Debug for NoopServerCertVerifier
impl Debug for NoopServerCertVerifier
Sourceimpl ServerCertVerifier for NoopServerCertVerifier
impl ServerCertVerifier for NoopServerCertVerifier
Sourcefn verify_server_cert( &self, _end_entity: &CertificateDer<'_>, _intermediates: &[CertificateDer<'_>], _server_name: &ServerName<'_>, _ocsp_response: &[u8], _now: UnixTime, ) -> Result<ServerCertVerified, RustlsError>
fn verify_server_cert( &self, _end_entity: &CertificateDer<'_>, _intermediates: &[CertificateDer<'_>], _server_name: &ServerName<'_>, _ocsp_response: &[u8], _now: UnixTime, ) -> Result<ServerCertVerified, RustlsError>
Verify the end-entity certificate
end_entity is valid for the hostname dns_name and chains to at least one trust anchor. Read moreSourcefn verify_tls12_signature( &self, _message: &[u8], _cert: &CertificateDer<'_>, _dss: &DigitallySignedStruct, ) -> Result<HandshakeSignatureValid, RustlsError>
fn verify_tls12_signature( &self, _message: &[u8], _cert: &CertificateDer<'_>, _dss: &DigitallySignedStruct, ) -> Result<HandshakeSignatureValid, RustlsError>
Verify a signature allegedly by the given server certificate. Read more
Sourcefn verify_tls13_signature( &self, _message: &[u8], _cert: &CertificateDer<'_>, _dss: &DigitallySignedStruct, ) -> Result<HandshakeSignatureValid, RustlsError>
fn verify_tls13_signature( &self, _message: &[u8], _cert: &CertificateDer<'_>, _dss: &DigitallySignedStruct, ) -> Result<HandshakeSignatureValid, RustlsError>
Verify a signature allegedly by the given server certificate. Read more
Sourcefn supported_verify_schemes(&self) -> Vec<SignatureScheme>
fn supported_verify_schemes(&self) -> Vec<SignatureScheme>
Return the list of SignatureSchemes that this verifier will handle, in
verify_tls12_signature and verify_tls13_signature calls. Read morefn requires_raw_public_keys(&self) -> bool
fn requires_raw_public_keys(&self) -> bool
Returns whether this verifier requires raw public keys as defined in RFC 7250.
fn root_hint_subjects(&self) -> Option<&[DistinguishedName]>
fn root_hint_subjects(&self) -> Option<&[DistinguishedName]>
Return the [
DistinguishedName]s of certificate authorities that this verifier trusts. Read moreAuto Trait Implementations
impl Freeze for NoopServerCertVerifier
impl RefUnwindSafe for NoopServerCertVerifier
impl Send for NoopServerCertVerifier
impl Sync for NoopServerCertVerifier
impl Unpin for NoopServerCertVerifier
impl UnwindSafe for NoopServerCertVerifier